<?php
/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 *
 * This is the query engine.
 */
/**
 * Tagger - Search for tags.
 * @author Greg
 */
class PHPDS_taggerListQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			tagID, tagObject, tagName, tagTarget, tagValue
		FROM
			_db_core_tags"; // WHERE tagTarget = '%s', tagObject = '%s', tagName = '%s', tagValue = '%s' ";
	protected $where = '1';

	public function extraBuild(&$parameters = null)
	{
		list($object, $name, $target) = $parameters;

		if (!empty($object)) $this->addWhere("tagObject = '%(object)s'");
		if (!empty($name)) $this->addWhere("tagName = '%(name)s'");
		if (!empty($target)) $this->addWhere("tagTarget = '%(target)s'");

		$parameters = array(
			'object' => $object,
			'name' => $name,
			'target' => $target
		);
		return parent::extraBuild($parameters);
	}

}

/**
 * Tagger - Look for tags.
 * @author Greg
 */
class PHPDS_taggerLookupQuery extends  PHPDS_taggerListQuery
{
	protected $singleRow = true;
	protected $focus = 'tagValue';

	public function getResults()
	{
		return $this->asOne(0, $this->focus);
	}
}

/**
 * Tagger - Add tags
 * @author Greg
 */
class PHPDS_taggerMarkQuery extends PHPDS_query
{
	protected $sql = "
		REPLACE INTO
			_db_core_tags
		SET
			tagObject = '%s', tagName = '%s', tagTarget = '%s', tagValue = '%s' ";
}

/**
 * Tagger - List available tags.
 * @author Jason Schoeman
 */
class PHPDS_taggerListTargetQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			tagName
		FROM
			_db_core_tags
		WHERE
			tagTarget = '%s'
		AND
			tagObject = '%s'
		";
}

/**
 * Tagger - Delete old tags.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteTagsQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_tags
		WHERE
			tagObject = '%s'
		AND
			tagTarget = '%s'
		";
}

/**
 * Tagger - Update tags to database.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_updateTagsQuery extends PHPDS_query
{
	protected $sql = "
		REPLACE INTO
			_db_core_tags (tagID, tagObject, tagName, tagTarget, tagValue)
		VALUES
			%s
		";

	/**
	 * Initiate query invoke command.
	 */
	public function invoke($properties)
	{
		list($object, $target, $value, $names) = $properties;
		if (! empty($target)) {
			// Lets just clean up old tags before we save.
			$this->db->invokeQuery('PHPDS_deleteTagsQuery', $object, $target);
			if (! empty($names)) {
				$new_tags_array = explode(",", $names);
				$new_tags = '';
				foreach ($new_tags_array as $tags) {
					$new_tags .= "('', '$object', '$tags', '$target', '$value'),";
				}
				if (! empty($new_tags)) {
					$new_tags = rtrim($new_tags,",");
					return parent::invoke(array($new_tags));
				}
			} else {
				return false;
			}
		}
	}
}
