<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */
class MenuItemAdmin extends PHPDS_controller
{

	/**
	 * @author Jason Schoeman [titan@phpdevshell.org], Ross Kuyper
	 * @since 01 July 2010
	 */
	public function execute()
	{
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Load Extra Classes ////////////////////////////////////////////////////////////////////////////////////////////////////
		$menu_structure = $this->factory('menuStructure'); //////////////////////////////////////////////////////////////////////
		$menu_array = $this->factory('menuArray'); //////////////////////////////////////////////////////////////////////////////
		// Require JS.
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/js/plugins/scrollTo/jquery.scrollTo-min.js');
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/js/ui.multiselect.js');
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/jquery.multiselect.js');
		$this->template->addJsFileToHead('themes/cloud/js/ajax/ajax.js');
		$js = <<<JS
			$(document).ready(function() {
				$('#menu_link_check').instantcheck({ controls: [ 'INPUT[name=menu_id]', 'INPUT[name=menu_link]', 'INPUT[name=menu_type]:checked', 'INPUT[name=plugin]' ], success: function (event, data) {
						if (data.title) $('#locationLabel').html(data.title);
					}
				});
				$('#plugin_check').instantcheck({ controls: [ 'INPUT[name=plugin]' ] });
				$('#alias_check').instantcheck({ controls: [ 'INPUT[name=menu_id]', 'INPUT[name=alias]' ] });
			});
JS;
		$this->template->addJsToHead($js);
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Define.
		$menu_type_selected_1 = 'checked';
		$menu_type_selected_2 = '';
		$menu_type_selected_3 = '';
		$menu_type_selected_4 = '';
		$menu_type_selected_5 = '';
		$menu_type_selected_6 = '';
		$menu_type_selected_7 = '';
		$menu_type_selected_8 = '';
		$hide_selected_1 = '';
		$hide_selected_2 = '';
		$hide_selected_3 = '';
		$hide_selected_4 = '';
		$hide_selected_5 = '';
		$new_window_selected_1 = '';
		$new_window_selected_2 = '';
		$edit['parent_menu_id'] = 0;
		$edit['menu_id'] = 0;
		$edit['plugin'] = '';
		$edit['menu_type'] = false;
		$edit['new_window'] = 0;
		$edit['menu_link'] = '';
		$edit['menu_name'] = '';
		$edit['alias'] = '';
		$edit['height'] = '';
		$edit['layout'] = '';
		$default_name = '';
		$found = false;
		$current_ranking = 0;
		$selected_user_roles = array();

		$icon_found = $this->template->icon('tick-circle', _('Item Found'));
		$icon_notfound = $this->template->icon('cross-circle', _('Item Not Found'));
		// Head.
		if ($this->POST('save') || !empty($edit_menu_id)) {
			$this->template->heading(_('Edit Menu Item'));
			$this->template->info(_('Edit an existing menu item. These are multiple navigational menu item types, users can access them where permission allows them.'));
		} else {
			$this->template->heading(_('New Menu Item'));
			$this->template->info(_('Create a new menu item. These are navigational menu items that will display in the menu list when created, users can then access them where permission allows them.'));
		}
		// Saving menu item.
		$edit_menu_id = $this->GET('em');
		if ($this->POST('save') || !empty($edit_menu_id) || $this->POST('new')) {
			// Check if it is a edit request or save request.
			if (! empty($edit_menu_id)) {
				// Get values of item to edit.
				$menu_array->loadMenuArray($edit_menu_id, false);
				// Save array value.
				$edit = $menu_array->menuArray[$edit_menu_id];
				// Define.
				if (empty($edit['height'])) $edit['height'] = false;
				if (empty($edit['new_window'])) $edit['new_window'] = 0;
				// Do extend column.
				switch ($edit['menu_type']) {
					case 2: $edit['link_to'] = $edit['extend'];
						break;
					case 3: $edit['link_to'] = $edit['extend'];
						break;
					case 6: $edit['link_to'] = $edit['extend'];
						break;
					case 7: $edit['height'] = $edit['extend'];
						break;
				}
				// Permissions.
				$selected_user_roles = $this->db->invokeQuery('PHPDS_getAdminMenuItemPermissionsQuery', $edit['menu_id']);
			}
			// On save assign $this->security->post global variable.
			if ($this->POST('save') || $this->POST('new')) {
				$defaults = array('menu_type' => 1, 'new_window' => 0);
				// Get the new variables on save.
				$edit = $this->POST(null, $defaults);
				  // menu_type
				  if (empty($edit['menu_type'])) $edit['menu_type'] = 1;
				  // new_window
				  if (empty($edit['new_window'])) $edit['new_window'] = 0;
				  
				// permission
				if (!empty($edit['permission'])) {
					foreach ($edit['permission'] as $role_id_save) {
						$selected_user_roles[$role_id_save] = 'selected';
					}
				}
			}
			// menu_id
			if (!empty($edit['plugin']) && !empty($edit['menu_link'])) {
				$edit['menu_id'] = $menu_structure->createMenuId($edit['plugin'], $edit['menu_link']);
			} else {
				$edit['menu_id'] = '';
			}
			/////////////////////////////////////////////////////////////////////////////////////////////
			// menu_type.
			$menu_type_selected_1 = '';
			switch ($edit['menu_type']) {
				// Plugin File.
				case 1:
					$menu_type_selected_1 = 'checked';
					// Remove first slash.
					$edit['menu_link'] = ltrim($edit['menu_link'], '/');
					// Check if we can find file.
					if (file_exists('plugins/' . $edit['plugin'] . '/controllers/' . $edit['menu_link'])) {
						$found = $icon_found;
					} else if (file_exists('plugins/' . $edit['plugin'] . '/' . $edit['menu_link'])) {
						$found = $icon_found;
					} else {
						$found = $icon_notfound;
					}
					break;
				// Link Existing Menu Item (Own Group).
				case 2:
					$menu_type_selected_2 = 'checked';
					$found = $icon_found;
					break;
				// Link Existing Menu Item (Jump To).
				case 3:
					$menu_type_selected_3 = 'checked';
					$found = $icon_found;
					break;
				// External File.
				case 4:
					$menu_type_selected_4 = 'checked';
					// Check if we can find file.
					if (file_exists($edit['menu_link'])) {
						$found = $icon_found;
					} else {
						$found = $icon_notfound;
					}
					break;
				// HTTP URL.
				case 5:
					$menu_type_selected_5 = 'checked';
					$found = $icon_found;
					break;
				// Empty Place Holder.
				case 6:
					$menu_type_selected_6 = 'checked';
					$found = $icon_found;
					break;
				// iFrame.
				case 7:
					$menu_type_selected_7 = 'checked';
					$found = $icon_found;
					break;
				// Cronjob Menu Item.
				case 8:
					$menu_type_selected_8 = 'checked';
					// Remove first slash.
					$edit['menu_link'] = ltrim($edit['menu_link'], '/');
					// Check if we can find file.
					if (file_exists('plugins/' . $edit['plugin'] . '/controllers/' . $edit['menu_link'])) {
						$found = $icon_found;
					} else if (file_exists('plugins/' . $edit['plugin'] . '/' . $edit['menu_link'])) {
						$found = $icon_found;
					} else {
						$found = $icon_notfound;
					}
					break;
			}
			/////////////////////////////////////////////////////////////////////////////////////////////
			// rank
			switch ($edit['rank']) {
				case 'last':
					$last_rank = $this->db->invokeQuery('PHPDS_lastRankMenuItemQuery', $edit['parent_menu_id']);
					break;
				case 'first':
					$last_rank = 1;
					break;
				default:
					$last_rank = $edit['rank'];
					break;
			}
			// Set auto selected dropdown parameters.
			// Ranking.
			$current_ranking = '<option value="' . $edit['rank'] . '" selected>' . _('Leave Current') . '</option>';
			/////////////////////////////////////////////////////////////////////////////////////////////
			/////////////////////////////////////////////////////////////////////////////////////////////
			// hide
			switch ($edit['hide']) {
				case 0:
					$hide_selected_1 = 'selected';
					break;
				case 1:
					$hide_selected_2 = 'selected';
					break;
				case 2:
					$hide_selected_3 = 'selected';
					break;
				case 3:
					$hide_selected_4 = 'selected';
					break;
				case 4:
					$hide_selected_5 = 'selected';
					break;
			}
			/////////////////////////////////////////////////////////////////////////////////////////////
			// new_window
			switch ($edit['new_window']) {
				case 0:
					$new_window_selected_1 = 'checked';
					break;
				case 1:
					$new_window_selected_2 = 'checked';
					break;
			}
			////////////////////////////////
			// Error checking.            //
			////////////////////////////////
			if (($this->POST('save') || $this->POST('new')) && $this->user->isRoot()) {

				// Define.
				$edit['extend'] = false;
				$edit['alias'] = $this->core->safeName($edit['alias']);
				// Error 1 = Check for empty fields.
				if (empty($edit['menu_link']) || empty($edit['plugin'])) {
					$this->template->warning(_('You did not complete all the required fields.'));
					$error[1] = true;
				}
				// Error 2 = See if menu item and link item is the same, that wont work!
				if ($edit['menu_id'] == $edit['link_to']) {
					$this->template->warning(_('You cannot link a menu item to itself!'));
					$error[2] = true;
				}
				// Error 4 = Check if menu is parent of itself.
				if ($edit['menu_id'] == $edit['parent_menu_id']) {
					$this->template->warning(_('You cannot have a menu item be a parent of itself! Please choose another parent for this item.'));
					$error[4] = true;
				}
				// Create file directory location.
				$menu_directory_c = $this->configuration['absolute_path'] . 'plugins/' . $edit['plugin'] . '/controllers/' . $edit['menu_link'];
				$menu_directory_n = $this->configuration['absolute_path'] . 'plugins/' . $edit['plugin'] . '/' . $edit['menu_link'];
				if (file_exists($menu_directory_c)) {
					$menu_directory = $menu_directory_c;
					$menu_dir_exists = true;
				} else if (file_exists($menu_directory_n)) {
					$menu_directory = $menu_directory_n;
					$menu_dir_exists = true;
				} else {
					$menu_dir_exists = false;
				}

				// Error Combined = Do appropriate checks on different menu types.
				switch ($edit['menu_type']) {
					// Plugin File.
					case 1:
						// Check if file exists.
						if (!$menu_dir_exists) {
							$this->template->warning(sprintf(_('I cannot find the plugin file you wish to create a menu item with, I looked in; <br /> %s'), $menu_directory));
							$error[3] = true;
						}
						break;
					// Link Existing Menu Item.
					case 2:
						// Check if linked item was selected.
						if (empty($edit['link_to'])) {
							$this->template->warning(_('When selecting to linked item from an existing menu item, you need to select a item to link with.'));
							$error[3] = true;
						}
						// Set correct extend variable.
						$edit['extend'] = $edit['link_to'];
						break;
					// Link Existing Menu Item (Jump To).
					case 3:
						// Check if linked item was selected.
						if (empty($edit['link_to'])) {
							$this->template->warning(_('When selecting to linked item from an existing menu item, you need to select a item to link with.'));
							$error[3] = true;
						}
						// Set correct extend variable.
						$edit['extend'] = $edit['link_to'];
						break;
					// External File.
					case 4:
						// Check if file exists.
						if (!file_exists($edit['menu_link'])) {
							$this->template->warning(sprintf(_('I cannot find the external file you wish to create a menu item with, I looked in; <br /> %s'), $edit['menu_link']));
							$error[3] = true;
						}
						break;
					// HTTP URL.
					case 5:
						$this->template->notice(_('a External URL was selected.'));
						break;
					// Empty Place Holder.
					case 6:
						// Check if linked item was selected.
						if (empty($edit['link_to'])) {
							$this->template->warning(_('When selecting to linked item from an existing menu item, you need to select a item to link with.'));
							$error[3] = true;
						}
						// Set correct extend variable.
						$edit['extend'] = $edit['link_to'];
						break;
					// iFrame.
					case 7:
						if (empty($edit['height'])) {
							$this->template->warning(_('You must provide iFrame with a height.'));
							$error[3] = true;
						}
						// Set correct extend variable.
						$edit['extend'] = $edit['height'];
						break;
					// Cron File.
					case 8:
						// Check if file exists.
						if (!file_exists($menu_directory)) {
							$this->template->warning(sprintf(_('I cannot find the plugin cron file you wish to create a menu item with, I looked in; <br /> %s'), $menu_directory));
							$error[3] = true;
						}
						break;
					// Plugin File.
					default:
						$this->template->warning(_('You need to select at least one menu type.'));
						$error[3] = true;
						break;
				}

				if (empty($error)) {
					// Insert new item into database.
					$menu_structure->insertMenu($edit['menu_id'], $edit['parent_menu_id'], $edit['menu_name'], $edit['menu_link'], $edit['plugin'], $edit['menu_type'], $edit['extend'], $edit['new_window'], $last_rank, $edit['hide'], $edit['template_id'], $edit['alias'], $edit['layout']);
					////////////////////////////////////
					// END Save new item to database. //
					////////////////////////////////////
					/////////////////////////
					// Permissions saving. //
					/////////////////////////
					// Delete old menu permissions.
					$this->db->invokeQuery("PHPDS_deleteOldMenuPermissionsQuery", $edit['menu_id']);

					// Make sure we have a value for a loop!
					$user_role_id_db = false;
					if (!empty($edit['permission'])) {
						// Define.
						// Save permissions.
						foreach ($edit['permission'] as $user_role_id) {
							$user_role_id_db .= "('', '$user_role_id', '{$edit['menu_id']}'),";
						}
					}
					// Set new assigned value.
					$user_role_id_db = rtrim($user_role_id_db, ',');
					if (!empty($user_role_id_db)) {
						// Insert menu permissions.
						$this->db->invokeQuery('PHPDS_insertMenuPermissionsQuery', $user_role_id_db);
					}
					// Set variable global for hooks.
					$this->template->global['menu_id'] = $edit['menu_id'];

					/////////////////////////////
					// END Permissions saving. //
					/////////////////////////////
					// Give OK message according to edit or newly saved.
					$this->template->ok(sprintf(_('Menu item %s was saved.'), $edit['menu_name']));
					// Check if we have an old menu id.
					if (!empty($edit['old_menu_id']) && $edit['old_menu_id'] != $edit['menu_id']) {
						$this->template->warning(sprintf(_('Note that a new menu item was created because of a change in its path or plugin structure. The new menu item id is %s and was derived from menu id %s.'), $edit['menu_id'], $edit['old_menu_id']));
					}
					// Save and new.
					if ($this->POST('new')) {
						$edit['menu_id'] = 0;
						$edit['menu_name'] = '';
						$edit['alias'] = '';
					}
				}
			}
		}

		//////////////////////////
		// Get all menu items. ///
		//////////////////////////
		$allMenuItems = $this->db->invokeQuery("PHPDS_getAllMenuItemsQuery", $edit);

		$edit = $allMenuItems['edit'];
		$show_existing_link = $allMenuItems['show_existing_link'];
		$show_parent = $allMenuItems['show_parent'];

		unset($allMenuItems);

		//////////////////////////
		// Get all user roles.  //
		//////////////////////////
		$allUserRoles = $this->db->invokeQuery('PHPDS_getAllUserRolesQuery', $edit, $selected_user_roles);

		$edit = $allUserRoles['edit'];
		$selected_user_roles = $allUserRoles['selected_user_roles'];

		unset($allUserRoles);

		//////////////////////////////////
		// Get all available templates. //
		//////////////////////////////////

		$allAvailTemplates = $this->db->invokeQuery('PHPDS_getAllAvailableTemplatesQuery', $edit);

		$edit = $allAvailTemplates['edit'];
		$template_option_ = $allAvailTemplates['template_option_'];

		unset($allAvailTemplates);

		///////////////////////////////////////////
		// Check if we have a default menu name. //
		///////////////////////////////////////////
		if (isset($this->lang[$edit['menu_link']]))
			$default_name = $this->lang[$edit['menu_link']];
		///////////////////////////////////////////
		///////////////////////////////////////////
		///////////////////////////////////////////

		// Load taglist.
		if (empty($edit['menu_name'])) {
			$tagname = $default_name;
		} else {
			$tagname = $edit['menu_name'];
		}
		$tagger = $this->tagger->tagArea('menu', $edit['menu_id'], $tagname);

		// Load views.
		$view = $this->factory('views');

		// Set Array.
		$view->set('e', $edit);

		// Set Values.
		$view->set('self_url', $this->navigation->selfUrl());
		$view->set('default_name', $default_name);
		$view->set('show_parent', $show_parent);
		$view->set('menu_type_selected_1', $menu_type_selected_1);
		$view->set('menu_type_selected_2', $menu_type_selected_2);
		$view->set('menu_type_selected_3', $menu_type_selected_3);
		$view->set('menu_type_selected_4', $menu_type_selected_4);
		$view->set('menu_type_selected_5', $menu_type_selected_5);
		$view->set('menu_type_selected_6', $menu_type_selected_6);
		$view->set('menu_type_selected_7', $menu_type_selected_7);
		$view->set('menu_type_selected_8', $menu_type_selected_8);
		$view->set('show_existing_link', $show_existing_link);
		$view->set('found', $found);
		$view->set('tagger', $tagger);
		$view->set('current_ranking', $current_ranking);
		$view->set('hide_selected_1', $hide_selected_1);
		$view->set('hide_selected_2', $hide_selected_2);
		$view->set('hide_selected_3', $hide_selected_3);
		$view->set('hide_selected_4', $hide_selected_4);
		$view->set('hide_selected_5', $hide_selected_5);
		$view->set('new_window_selected_1', $new_window_selected_1);
		$view->set('new_window_selected_2', $new_window_selected_2);
		$view->set('template_option_', $template_option_);

		// Output Template.
		$view->show();
	}

	/**
	 * Check via ajax if files exist.
	 *
	 * @return string
	 */
	public function viaAJAX()
	{
		$menu_id = $this->GET('menu_id');
		$menu_type = $this->GET('menu_type');
		$plugin = $this->GET('plugin');

		$_target = $this->GET('_target');

		$result = array(
			'result' => 'na',
			'title' => _('URL/Path Location')
		);

		switch ($_target) {
			case 'menu_link_check':
				switch ($menu_type) {
					case 1:
						$menu_link = $this->GET('menu_link');
						if ($menu_link && $plugin) {
							if (file_exists(BASEPATH . 'plugins/' . $plugin . '/controllers/' . $menu_link)) {
								$path1 = BASEPATH . 'plugins/' . $plugin . '/controllers';
								$path2 = $path1 . '/' . $menu_link;
							} else if (file_exists(BASEPATH . 'plugins/' . $plugin . '/' . $menu_link)) {
								$path1 = BASEPATH . 'plugins/' . $plugin;
								$path2 = $path1 . '/' . $menu_link;
							} else {
								$path1 = BASEPATH . 'plugins/' . $plugin;
								$path2 = $path1 . '/' . $menu_link;
							}

							$result = array(
								'result' => (is_readable($path1) && is_dir($path1) && is_readable($path2) && is_file($path2)) ? 'yes' : 'no',
								'tooltip' => $path2,
								'title' => 'Relative path to the PHP file'
							);
						}
						break;
					case 2:
						$menu_link = $this->GET('menu_link');
						if ($menu_id && $menu_link) {
							$exists = $this->db->invokeQuery('PHPDS_findMenuLinkUnicity', $menu_link, $menu_id);
							$result = array(
								'result' => $exists ? 'error' : 'yes',
								'title' => 'Virtual path (should be unique to this script)'
							);
						}
						break;
				}
				break;
			case 'plugin_check':
				if ($plugin) {
					$path1 = BASEPATH . 'plugins/' . $plugin;
					$result = array(
						'result' => is_readable($path1) && is_dir($path1) ? 'yes' : 'no',
						'tooltip' => $path1
					);
				}
				break;
			case 'alias_check':
				$alias = $this->GET('alias');
				if ($alias) {
					$exists = $this->db->invokeQuery('PHPDS_findMenuAliasUnicity', $alias, $menu_id);
					$result = array(
						'result' => $exists ? 'error' : 'yes'
					);
				}
				break;
		}

		return $result;
	}
}

return 'MenuItemAdmin';