<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * Controller Class: User Role Administration
 * @author Jason Schoeman
 * @return string
 */
class UserRoleAdmin extends PHPDS_controller
{

	/**
	 * Execute Controller
	 * @author Jason Schoeman
	 */
	public function execute()
	{
		// Require JS.
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/js/plugins/scrollTo/jquery.scrollTo-min.js');
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/js/ui.multiselect.js');
		$this->template->addJsFileToHead('themes/cloud/js/multiselect/jquery.multiselect.js');
		// Define.
		$user_role_id = (int) 0;
		$user_role_name = (string) '';
		$user_role_note = (string) '';
		$user_role_id_db = (int) 0;
		$selected_menu = array();

		// Header
		if (!empty($this->security->get['er']) || !empty($this->security->post['save'])) {
			$this->template->heading(_('Edit Role Names'));
			$this->template->info(_('This script is used to edit existing user roles. After a user role has been modified you can assign permission to the user role. After permissions are assigned you can assign users to the user role. Custom menu items can also be assigned to user roles, this allows you to keep certain custom applications seperate.'));
		} else {
			$this->template->heading(_('Add User Role'));
			$this->template->info(_('This script is used to add user roles. After a user role has been added you can assign permission to the user role. After permissions are assigned you can assign users to the user role. Custom menu items can also be assigned to user roles, this allows you to keep certain custom applications seperate.'));
		}
		// Post and save.
		if (!empty($this->security->get['er']) || !empty($this->security->post['save']) || !empty($this->security->post['new'])) {

			// If item is in edit mode.
			if (!empty($this->security->get['er'])) {
				// Get basic role information.
				$select_user_role_array = $this->db->invokeQuery('PHPDS_readRoleUserQuery', $this->security->get['er']);
				$user_role_id = $select_user_role_array['user_role_id'];
				$user_role_name = $select_user_role_array['user_role_name'];
				$user_role_note = $select_user_role_array['user_role_note'];
				// Get selected permissions.
				$selected_menu = $this->db->invokeQuery('PHPDS_readRoleMenuQuery', $this->security->get['er']);
			}
			// If item gets saved.
			if (!empty($this->security->post['save']) || !empty($this->security->post['new'])) {
				if (!empty($this->security->post['user_role_id'])) {
					$user_role_id = $this->security->post['user_role_id'];
				} else {
					$user_role_id = 0;
				}
				$user_role_name = $this->security->post['user_role_name'];
				$user_role_note = $this->security->post['user_role_note'];
				// Define.
				if (!empty($this->security->post['permission'])) {
					$permission = $this->security->post['permission'];
				} else {
					$permission = false;
				}

				// Some minor error checking.
				if (empty($user_role_name)) {
					$this->template->warning(_('You need to provide values for all fields, please try again.'));
					$error[1] = true;
				} else {
					// Does the record already exist.
					if ($this->db->doesRecordExist('_db_core_user_roles', 'user_role_name', "$user_role_name", 'user_role_id', "$user_role_id") == true) {
						$this->template->warning(sprintf(_('There is already a role record named %s. Cannot duplicate.'), $user_role_name));
						$error[2] = true;
					}
				}
				// If everything is ok we can now save.
				if (empty($error)) {
					// Get last inserted ID.
					$user_role_id = $this->db->invokeQuery('PHPDS_writeRoleQuery', $user_role_id, $user_role_name, $user_role_note);
					// Set variable global for hooks.
					$this->template->global['user_role_id'] = $user_role_id;
					/////////////////////////
					// Permissions saving. //
					/////////////////////////
					// Delete old menu permissions.
					$this->db->invokeQuery('PHPDS_deletePermissionsQuery', $user_role_id);
					// Write new permissions.
					$this->db->invokeQuery('PHPDS_writePermissionsQuery', $user_role_id, $permission);
					// Assign form selection.
					if (!empty($permission)) {
						// Save permissions.
						foreach ($permission as $menu_id) {
							// Also set selected role menu items.
							$selected_menu[$menu_id] = 'selected';
						}
					}
					/////////////////////////////
					// END Permissions saving. //
					/////////////////////////////
					// Show item updated.
					$this->template->ok(sprintf(_('You have saved user role %s.'), $user_role_name));
					// Save and create new item.
					if (!empty($this->security->post['new'])) {
						$user_role_id = 0;
						$user_role_name = '';
						$user_role_note = '';
					}
				}
			}
		}
		//////////////////////////
		// Get all menu items. ///
		//////////////////////////
		$menu_item_options = $this->db->invokeQuery('PHPDS_readMenusQuery', $selected_menu);

		////////////////////////////////
		// END...                     //
		////////////////////////////////

		// Load taglist.
		$tagger = $this->tagger->tagArea('role', $user_role_id, $user_role_name);

		// Load views.
		$view = $this->factory('views');

		// Set Values.
		$view->set('self_url', $this->navigation->selfUrl());
		$view->set('user_role_id', $user_role_id);
		$view->set('user_role_name', $user_role_name);
		$view->set('user_role_note', $user_role_note);
		$view->set('tagger', $tagger);
		$view->set('menus_select', $menu_item_options);

		// Output Template.
		$view->show();
	}
}

return 'UserRoleAdmin';