<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * Controller Class: Email admin for queries.
 * @author Jason Schoeman
 * @return string
 */
class EmailAdmin extends PHPDS_controller
{

	/**
	 * Execute Controller
	 * @author Jason Schoeman
	 */
	public function execute()
	{
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Load Extra Classes ////////////////////////////////////////////////////////////////////////////////////////////////////
		$email = $this->factory('mailer');
		$wysiwyg = $this->factory('wysiwygEditor');
		$wysiwyg->wysiwyg_load();

		$this->template->heading(_('Send Query to System Administrator'));
		$this->template->info(_('You may use this form to send an email query to the System Administrator.'));

		// If the user posts, run the checks and send the email script.
		if (!empty($this->security->post['send_mail'])) {
			// Email error checking.
			if (!empty($this->security->post['email_from']) && !empty($this->security->post['subject']) && !empty($this->security->post['message'])) {
				// Validate email address for correct format.
				if (!$email->validate($this->security->post['email_from'])) {
					$error[1] = true;
					$this->template->warning(_('The email address you specified seems to be invalid. Please verify that your email address was entered correctly.'), false, false);
				}
				// If user tries to send another email in less then 60 seconds, reply with an error.
				if (!empty($_SESSION['hold'])) {
					$seconds_ = $this->configuration['time'] - $_SESSION['hold'];
					if ($seconds_ < 60) {
						$this->template->warning(sprintf(_('You can not send another message within 60 seconds, you have waited %s seconds.'), $seconds_), false, false);
						$error[2] = true;
					}
				}

				if (empty($error)) {
					// Collect email data.
					$settings_ = $this->db->essentialSettings;
					$admin_email = $settings_['setting_admin_email'];
					$from = $this->security->post['email_from'];
					$subject = $this->security->post['subject'];
					// Decode the message to html characters.
					$message = $this->template->html_entity_decode($this->security->post['message']);
					if ($email->sendmail("$admin_email", $subject, $message, "$from", false, false, false, false, false, 'text/html')) {
						$this->template->ok(sprintf(_('The email was sent successfully from %s.'), $from));
						$_SESSION['hold'] = $this->configuration['time'];
					} else {
						$this->template->warning(_('An error occurred while trying to send this email. Please notify the Administrator of this problem.'));
					}
				}
			} else {
				$this->template->warning(_('You have missed fields for sending a query to the Administrator, try again please!'), false, false);
			}
		} else {
			$this->security->post['email_from'] = false;
			$this->security->post['subject'] = false;
			$this->security->post['message'] = false;
		}

		// Load views.
		$view = $this->factory('views');

		// Set Buttons.
		$view->set('send_message', _('Send Message'));

		// Set Values.
		$view->set('self_url', $this->navigation->selfUrl());
		$view->set('email_from', $this->security->post['email_from']);
		$view->set('user_email', $this->configuration['user_email']);
		$view->set('subject', $this->security->post['subject']);
		$view->set('message', $this->security->post['message']);
		$view->set('post_validation', $this->security->postValidation());

		// Output Template.
		$view->show();
	}
}

return 'EmailAdmin';
